==> innoextract_1.4.orig.tar.gz: innoextract-1.4/src/crypto/hasher.cpp <==
/*
 * Copyright (C) 2011 Daniel Scharrer
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the author(s) be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 */

#include "crypto/hasher.hpp"

namespace crypto {

hasher::hasher(const hasher & o) {
	
	type = o.type;
	
	switch(type) {
		case crypto::Adler32: adler32 = o.adler32; break;
		case crypto::CRC32: crc32 = o.crc32; break;
		case crypto::MD5: md5 = o.md5; break;
		case crypto::SHA1: sha1 = o.sha1; break;
	};
}

void hasher::init(checksum_type newType) {
	
	type = newType;
	
	switch(type) {
		case crypto::Adler32: adler32.init(); break;
		case crypto::CRC32: crc32.init(); break;
		case crypto::MD5: md5.init(); break;
		case crypto::SHA1: sha1.init(); break;
	};
}

void hasher::update(const char * data, size_t size) {
	
	switch(type) {
		case crypto::Adler32: adler32.update(data, size); break;
		case crypto::CRC32: crc32.update(data, size); break;
		case crypto::MD5: md5.update(data, size); break;
		case crypto::SHA1: sha1.update(data, size); break;
	};
}

checksum hasher::finalize() {
	
	checksum result;
	
	result.type = type;
	
	switch(type) {
		case crypto::Adler32: result.adler32 = adler32.finalize(); break;
		case crypto::CRC32: result.crc32 = crc32.finalize(); break;
		case crypto::MD5: md5.finalize(result.md5); break;
		case crypto::SHA1: sha1.finalize(result.sha1); break;
	};
	
	return result;
}

} // namespace crypto

==> innoextract_1.5.orig.tar.gz: innoextract-1.5/src/crypto/hasher.cpp <==
/*
 * Copyright (C) 2011-2014 Daniel Scharrer
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the author(s) be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 */

#include "crypto/hasher.hpp"

namespace crypto {

hasher::hasher(const hasher & o) {
	
	type = o.type;
	
	switch(type) {
		case crypto::Adler32: adler32 = o.adler32; break;
		case crypto::CRC32: crc32 = o.crc32; break;
		case crypto::MD5: md5 = o.md5; break;
		case crypto::SHA1: sha1 = o.sha1; break;
	};
}

hasher::hasher(checksum_type type) : type(type) {
	
	switch(type) {
		case crypto::Adler32: adler32.init(); break;
		case crypto::CRC32: crc32.init(); break;
		case crypto::MD5: md5.init(); break;
		case crypto::SHA1: sha1.init(); break;
	};
}

void hasher::update(const char * data, size_t size) {
	
	switch(type) {
		case crypto::Adler32: adler32.update(data, size); break;
		case crypto::CRC32: crc32.update(data, size); break;
		case crypto::MD5: md5.update(data, size); break;
		case crypto::SHA1: sha1.update(data, size); break;
	};
}

checksum hasher::finalize() {
	
	checksum result;
	
	result.type = type;
	
	switch(type) {
		case crypto::Adler32: result.adler32 = adler32.finalize(); break;
		case crypto::CRC32: result.crc32 = crc32.finalize(); break;
		case crypto::MD5: md5.finalize(result.md5); break;
		case crypto::SHA1: sha1.finalize(result.sha1); break;
	};
	
	return result;
}

} // namespace crypto
